<script setup lang="ts">
import { IconifyIcon } from '@vben/icons';

import { Input } from 'ant-design-vue';

import { generateCode } from '#/api/eims/utils';

defineOptions({ name: 'CodeInput' });

/**
 * 特别注意，单号根据前缀生成
 * BXD-报修单
 */

const props = defineProps({
  disabled: {
    default: false,
    type: Boolean
  },
  prefix: {
    default: null,
    type: String
  },
  placeholder: {
    default: '自动生成',
    type: String
  }
});

const value = defineModel<string>('value', {
  required: false,
  type: String
});

async function refreshCode() {
  // 根据
  // value.value = buildUUID();
  const code = await generateCode(props.prefix);
  value.value = code;
}

/**
 * 万一要在每次新增时打开Drawer刷新
 * 需要调用实例方法
 */
defineExpose({ refreshCode });
</script>

<template>
  <Input v-model:value="value" :disabled="disabled" :placeholder="placeholder">
    <template v-if="!disabled" #addonAfter>
      <a-button type="primary" @click="refreshCode">
        <div class="flex items-center gap-[4px]">
          <IconifyIcon icon="charm:refresh" />
          <span>自动生成</span>
        </div>
      </a-button>
    </template>
  </Input>
</template>

<style lang="scss" scoped>
:deep(.ant-input-group-addon) {
  padding: 0;
  border: none;
}

:deep(.ant-btn-primary) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
</style>
